Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: third_party/ffmpeg/include/libavutil/rational.h

Issue 56129: Update public FFmpeg header files from r16647 to r18286. (Closed)
Patch Set: Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/ffmpeg/include/libavutil/random.h ('k') | third_party/ffmpeg/using_ffmpeg.vsprops » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/ffmpeg/include/libavutil/rational.h
diff --git a/third_party/ffmpeg/include/libavutil/rational.h b/third_party/ffmpeg/include/libavutil/rational.h
index 70b7735da310c16c722b4ede7c1f4660c5cf2cb3..5ee70c9bedef6f8f9500dc012c79df9b7a141481 100644
--- a/third_party/ffmpeg/include/libavutil/rational.h
+++ b/third_party/ffmpeg/include/libavutil/rational.h
@@ -1,5 +1,5 @@
/*
- * Rational numbers
+ * rational numbers
* Copyright (c) 2003 Michael Niedermayer <michaelni@gmx.at>
*
* This file is part of FFmpeg.
@@ -20,8 +20,8 @@
*/
/**
- * @file rational.h
- * Rational numbers.
+ * @file libavutil/rational.h
+ * rational numbers
* @author Michael Niedermayer <michaelni@gmx.at>
*/
@@ -32,7 +32,7 @@
#include "common.h"
/**
- * Rational number num/den.
+ * rational number numerator/denominator
*/
typedef struct AVRational{
int num; ///< numerator
@@ -40,10 +40,10 @@ typedef struct AVRational{
} AVRational;
/**
- * Compare two rationals.
+ * Compares two rationals.
* @param a first rational
* @param b second rational
- * @return 0 if a==b, 1 if a>b and -1 if a<b.
+ * @return 0 if a==b, 1 if a>b and -1 if a<b
*/
static inline int av_cmp_q(AVRational a, AVRational b){
const int64_t tmp= a.num * (int64_t)b.den - b.num * (int64_t)a.den;
@@ -53,7 +53,7 @@ static inline int av_cmp_q(AVRational a, AVRational b){
}
/**
- * Rational to double conversion.
+ * Converts rational to double.
* @param a rational to convert
* @return (double) a
*/
@@ -62,46 +62,46 @@ static inline double av_q2d(AVRational a){
}
/**
- * Reduce a fraction.
+ * Reduces a fraction.
* This is useful for framerate calculations.
- * @param dst_nom destination numerator
+ * @param dst_num destination numerator
* @param dst_den destination denominator
* @param nom source numerator
* @param den source denominator
* @param max the maximum allowed for dst_nom & dst_den
* @return 1 if exact, 0 otherwise
*/
-int av_reduce(int *dst_nom, int *dst_den, int64_t nom, int64_t den, int64_t max);
+int av_reduce(int *dst_num, int *dst_den, int64_t num, int64_t den, int64_t max);
/**
* Multiplies two rationals.
- * @param b first rational.
- * @param c second rational.
- * @return b*c.
+ * @param b first rational
+ * @param c second rational
+ * @return b*c
*/
AVRational av_mul_q(AVRational b, AVRational c) av_const;
/**
* Divides one rational by another.
- * @param b first rational.
- * @param c second rational.
- * @return b/c.
+ * @param b first rational
+ * @param c second rational
+ * @return b/c
*/
AVRational av_div_q(AVRational b, AVRational c) av_const;
/**
* Adds two rationals.
- * @param b first rational.
- * @param c second rational.
- * @return b+c.
+ * @param b first rational
+ * @param c second rational
+ * @return b+c
*/
AVRational av_add_q(AVRational b, AVRational c) av_const;
/**
* Subtracts one rational from another.
- * @param b first rational.
- * @param c second rational.
- * @return b-c.
+ * @param b first rational
+ * @param c second rational
+ * @return b-c
*/
AVRational av_sub_q(AVRational b, AVRational c) av_const;
@@ -109,7 +109,7 @@ AVRational av_sub_q(AVRational b, AVRational c) av_const;
* Converts a double precision floating point number to a rational.
* @param d double to convert
* @param max the maximum allowed numerator and denominator
- * @return (AVRational) d.
+ * @return (AVRational) d
*/
AVRational av_d2q(double d, int max) av_const;
« no previous file with comments | « third_party/ffmpeg/include/libavutil/random.h ('k') | third_party/ffmpeg/using_ffmpeg.vsprops » ('j') | no next file with comments »
@@ -62,46 +62,46 @@ static inline double av_q2d(AVRational a){
* @param dst_den destination denominator
- * @param nom source numerator
+ * @param num source numerator
* @param den source denominator
@@ -62,46 +62,46 @@ static inline double av_q2d(AVRational a){
* @param den source denominator
- * @param max the maximum allowed for dst_nom & dst_den
+ * @param max the maximum allowed for dst_num & dst_den
* @return 1 if exact, 0 otherwise
*/

Powered by Google App Engine
This is Rietveld 408576698